==> kdebindings-3.3.2.tar.bz2: kdebindings-3.3.2/kjsembed/jsvalueproxy_imp.cpp <==
/*
 *  Copyright (C) 2001-2003, Richard J. Moore <rich@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 */

#include <qvariant.h>
#include "global.h"

#include <kjs/interpreter.h>
#include <kjs/types.h>
#include <kjs/ustring.h>

#include "jsobjectproxy.h"
#include "jsobjectproxy_imp.h"

#include "jsvalueproxy.h"
#include "jsvalueproxy_imp.h"

namespace KJSEmbed {
namespace Bindings {

JSValueProxyImp::JSValueProxyImp( KJS::ExecState *exec, int mid, const JSValueProxy *parent )
    : JSProxyImp(exec), id(mid), proxy(parent)
{
}

JSValueProxyImp::~JSValueProxyImp()
{
}

KJS::Value JSValueProxyImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
    switch( id ) {
	case MethodTypeName:
	{
	    return KJS::String( proxy->typeName() );
	}
	break;
    }

    return KJS::ObjectImp::call( exec, self, args );
}

} // namespace Bindings
} // namespace KJSEmbed

// Local Variables:
// c-basic-offset: 4
// End:

==> kdebindings-3.4.2.tar.bz2: kdebindings-3.4.2/kjsembed/jsvalueproxy_imp.cpp <==
/*
 *  Copyright (C) 2001-2003, Richard J. Moore <rich@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 */

#include <qvariant.h>
#include "global.h"

#include <kjs/interpreter.h>
#include <kjs/types.h>
#include <kjs/ustring.h>

#include "jsobjectproxy.h"
#include "jsobjectproxy_imp.h"

#include "jsvalueproxy.h"
#include "jsvalueproxy_imp.h"

using namespace KJS;

namespace KJSEmbed {
namespace Bindings {

JSValueProxyImp::JSValueProxyImp( KJS::ExecState *exec, int mid, const JSValueProxy *parent )
    : JSProxyImp(exec), id(mid), proxy(parent)
{
}

JSValueProxyImp::~JSValueProxyImp()
{
}

KJS::Value JSValueProxyImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
    switch( id ) {
	case MethodTypeName:
	{
	    return KJS::String( proxy->typeName() );
	}
	break;
    }

    return ObjectImp::call( exec, self, args );
}

} // namespace Bindings
} // namespace KJSEmbed

// Local Variables:
// c-basic-offset: 4
// End:
